==> react-lds-8.7.0.tgz: package/es/components/Combobox/BaseCombobox.js <==
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.object.set-prototype-of";
import "core-js/modules/es7.object.get-own-property-descriptors";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es6.object.assign";
import "core-js/modules/es6.regexp.replace";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { keys.push.apply(keys, Object.getOwnPropertySymbols(object)); } if (enumerableOnly) keys = keys.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { InputRaw } from '../Form';
import ComboboxCore from './components/ComboboxCore';
import ComboboxListbox from './components/ComboboxListbox';
import { BaseDropdownItem } from './components/DropdownItems';
import { itemType } from './utils/constants';
export var defaultBaseComboboxInputRenderer = function defaultBaseComboboxInputRenderer(inputProps, opts) {
  var isMultiSelect = opts.isMultiSelect,
      labelMultiSelect = opts.labelMultiSelect,
      selectedItems = opts.selectedItems;
  var len = selectedItems.length;
  var inputValue = '';

  if (len === 1 && !isMultiSelect) {
    var selection = selectedItems[0];
    if (selection && selection.label) inputValue = selection.label;
  } else if (len > 0) {
    inputValue = labelMultiSelect.replace(/%n/gm, "".concat(len));
  }

  return React.createElement(InputRaw, _extends({}, inputProps, {
    iconRight: "down",
    readOnly: true,
    type: "text",
    value: inputValue
  }));
};
export var defaultBaseComboboxItemRenderer = function defaultBaseComboboxItemRenderer(resultProps, opts) {
  var id = resultProps.id;
  var makeSelectHandler = opts.makeSelectHandler,
      selectedItems = opts.selectedItems;

  var baseResultsProps = _objectSpread({}, resultProps, {
    isMultiSelect: selectedItems.length > 1,
    key: id,
    onSelect: makeSelectHandler(id)
  });

  return React.createElement(BaseDropdownItem, baseResultsProps);
};
export var BaseCombobox =
/*#__PURE__*/
function (_Component) {
  _inherits(BaseCombobox, _Component);

  function BaseCombobox() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, BaseCombobox);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(BaseCombobox)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "renderInput", function (inputProps, opts) {
      var _this$props = _this.props,
          labelMultiSelect = _this$props.labelMultiSelect,
          renderInput = _this$props.renderInput;
      return renderInput(inputProps, _objectSpread({}, opts, {
        labelMultiSelect: labelMultiSelect
      }));
    });

    return _this;
  }

  _createClass(BaseCombobox, [{
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          labelMultiSelect = _this$props2.labelMultiSelect,
          rest = _objectWithoutProperties(_this$props2, ["labelMultiSelect"]);

      return React.createElement(ComboboxCore, _extends({}, rest, {
        renderInput: this.renderInput
      }));
    }
  }]);

  return BaseCombobox;
}(Component);

_defineProperty(BaseCombobox, "defaultProps", {
  closeOnSelect: true,
  comboboxClassName: null,
  dropdownClassName: null,
  error: null,
  height: 5,
  hideErrorMessage: false,
  hideLabel: false,
  isLoading: false,
  isMultiSelect: false,
  isRequired: false,
  items: [],
  labelListbox: null,
  labelMultiSelect: '%n Option(s) Selected',
  renderInput: defaultBaseComboboxInputRenderer,
  renderItem: defaultBaseComboboxItemRenderer,
  renderItemsAppended: null,
  renderItemsPrepended: null,
  renderListbox: function renderListbox(listboxProps) {
    return React.createElement(ComboboxListbox, listboxProps);
  },
  selectedItems: []
});

BaseCombobox.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * See `ComboboxCore` or the Storybook stories for more information
   */
  closeOnSelect: PropTypes.bool,
  comboboxClassName: PropTypes.string,
  dropdownClassName: PropTypes.string,
  error: PropTypes.string,
  height: PropTypes.oneOf([5, 7, 10]),
  hideLabel: PropTypes.bool,
  id: PropTypes.string.isRequired,
  hideErrorMessage: PropTypes.bool,
  isLoading: PropTypes.bool,
  isMultiSelect: PropTypes.bool,
  isOpen: PropTypes.bool.isRequired,
  isRequired: PropTypes.bool,
  items: PropTypes.arrayOf(itemType),
  label: PropTypes.node.isRequired,
  labelListbox: PropTypes.string,

  /**
   * Text shown in Dropdown input when more than one item is selected.
   * Use `%n` to merge in the count of items currently selected
   */
  labelMultiSelect: PropTypes.string,
  placeholder: PropTypes.string.isRequired,
  onSelect: PropTypes.func.isRequired,
  onToggle: PropTypes.func.isRequired,
  renderInput: PropTypes.func,
  renderItem: PropTypes.func,
  renderItemsAppended: PropTypes.func,
  renderItemsPrepended: PropTypes.func,
  renderListbox: PropTypes.func,
  selectedItems: PropTypes.arrayOf(itemType)
} : {};
export var Picklist = BaseCombobox;

==> react-lds-9.1.0.tgz: package/es/components/Combobox/BaseCombobox.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.filter";
import "core-js/modules/es.array.for-each";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.get-own-property-descriptor";
import "core-js/modules/es.object.get-own-property-descriptors";
import "core-js/modules/es.object.get-prototype-of";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.set-prototype-of";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.regexp.exec";
import "core-js/modules/es.string.iterator";
import "core-js/modules/es.string.replace";
import "core-js/modules/web.dom-collections.for-each";
import "core-js/modules/web.dom-collections.iterator";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { InputRaw } from '../Form';
import ComboboxCore from './components/ComboboxCore';
import ComboboxListbox from './components/ComboboxListbox';
import { BaseDropdownItem } from './components/DropdownItems';
import { itemType } from './utils/constants';
export var defaultBaseComboboxInputRenderer = function defaultBaseComboboxInputRenderer(inputProps, opts) {
  var isMultiSelect = opts.isMultiSelect,
      labelMultiSelect = opts.labelMultiSelect,
      selectedItems = opts.selectedItems;
  var len = selectedItems.length;
  var inputValue = '';

  if (len === 1 && !isMultiSelect) {
    var selection = selectedItems[0];
    if (selection && selection.label) inputValue = selection.label;
  } else if (len > 0) {
    inputValue = labelMultiSelect.replace(/%n/gm, "".concat(len));
  }

  return React.createElement(InputRaw, _extends({}, inputProps, {
    iconRight: "down",
    readOnly: true,
    type: "text",
    value: inputValue
  }));
};
export var defaultBaseComboboxItemRenderer = function defaultBaseComboboxItemRenderer(resultProps, opts) {
  var id = resultProps.id;
  var makeSelectHandler = opts.makeSelectHandler,
      selectedItems = opts.selectedItems;

  var baseResultsProps = _objectSpread({}, resultProps, {
    isMultiSelect: selectedItems.length > 1,
    key: id,
    onSelect: makeSelectHandler(id)
  });

  return React.createElement(BaseDropdownItem, baseResultsProps);
};
export var BaseCombobox =
/*#__PURE__*/
function (_Component) {
  _inherits(BaseCombobox, _Component);

  function BaseCombobox() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, BaseCombobox);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(BaseCombobox)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "renderInput", function (inputProps, opts) {
      var _this$props = _this.props,
          labelMultiSelect = _this$props.labelMultiSelect,
          renderInput = _this$props.renderInput;
      return renderInput(inputProps, _objectSpread({}, opts, {
        labelMultiSelect: labelMultiSelect
      }));
    });

    return _this;
  }

  _createClass(BaseCombobox, [{
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          labelMultiSelect = _this$props2.labelMultiSelect,
          rest = _objectWithoutProperties(_this$props2, ["labelMultiSelect"]);

      return React.createElement(ComboboxCore, _extends({}, rest, {
        renderInput: this.renderInput
      }));
    }
  }]);

  return BaseCombobox;
}(Component);

_defineProperty(BaseCombobox, "defaultProps", {
  closeOnSelect: true,
  comboboxClassName: null,
  dropdownClassName: null,
  error: null,
  height: 5,
  hideErrorMessage: false,
  hideLabel: false,
  isLoading: false,
  isMultiSelect: false,
  isRequired: false,
  items: [],
  labelListbox: null,
  labelMultiSelect: '%n Option(s) Selected',
  renderInput: defaultBaseComboboxInputRenderer,
  renderItem: defaultBaseComboboxItemRenderer,
  renderItemsAppended: null,
  renderItemsPrepended: null,
  renderListbox: function renderListbox(listboxProps) {
    return React.createElement(ComboboxListbox, listboxProps);
  },
  selectedItems: []
});

BaseCombobox.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * See `ComboboxCore` or the Storybook stories for more information
   */
  closeOnSelect: PropTypes.bool,
  comboboxClassName: PropTypes.string,
  dropdownClassName: PropTypes.string,
  error: PropTypes.string,
  height: PropTypes.oneOf([5, 7, 10]),
  hideLabel: PropTypes.bool,
  id: PropTypes.string.isRequired,
  hideErrorMessage: PropTypes.bool,
  isLoading: PropTypes.bool,
  isMultiSelect: PropTypes.bool,
  isOpen: PropTypes.bool.isRequired,
  isRequired: PropTypes.bool,
  items: PropTypes.arrayOf(itemType),
  label: PropTypes.node.isRequired,
  labelListbox: PropTypes.string,

  /**
   * Text shown in Dropdown input when more than one item is selected.
   * Use `%n` to merge in the count of items currently selected
   */
  labelMultiSelect: PropTypes.string,
  placeholder: PropTypes.string.isRequired,
  onSelect: PropTypes.func.isRequired,
  onToggle: PropTypes.func.isRequired,
  renderInput: PropTypes.func,
  renderItem: PropTypes.func,
  renderItemsAppended: PropTypes.func,
  renderItemsPrepended: PropTypes.func,
  renderListbox: PropTypes.func,
  selectedItems: PropTypes.arrayOf(itemType)
} : {};
export var Picklist = BaseCombobox;
